pub struct Stats { /* private fields */ }Expand description
A struct representing a Discord bot’s statistics.
Examples
Solely from a server count:
use topgg::Stats;
let _stats = Stats::from(12345);Server count with a shard count:
use topgg::Stats;
let server_count = 12345;
let shard_count = 10;
let _stats = Stats::from_count(server_count, Some(shard_count));Solely from shards information:
use topgg::Stats;
// the shard posting this data has 456 servers.
let _stats = Stats::from_shards([123, 456, 789], Some(1));Implementations
Sourceimpl Stats
impl Stats
Sourcepub fn shard_count(&self) -> usize
pub fn shard_count(&self) -> usize
The amount of shards this Discord bot has.
Sourcepub fn server_count(&self) -> Option<usize>
pub fn server_count(&self) -> Option<usize>
The amount of servers this bot is in. None if such information is publy unavailable.
Sourceimpl Stats
impl Stats
Sourcepub fn from_context(context: &Context) -> Self
Available on crate feature serenity-cached only.
pub fn from_context(context: &Context) -> Self
serenity-cached only.Sourcepub const fn from_count(server_count: usize, shard_count: Option<usize>) -> Self
pub const fn from_count(server_count: usize, shard_count: Option<usize>) -> Self
Creates a Stats struct based on total server and optionally, shard count data.
Sourcepub fn from_shards<A>(shards: A, shard_index: Option<usize>) -> Selfwhere
A: IntoIterator<Item = usize>,
pub fn from_shards<A>(shards: A, shard_index: Option<usize>) -> Selfwhere
A: IntoIterator<Item = usize>,
Creates a Stats struct based on an array of server count per shard and optionally the index (to the array) of shard posting this data.
Panics
Panics if the shard_index argument is Some yet it’s out of range of the shards array.
Examples
Basic usage:
use topgg::Stats;
// the shard posting this data has 456 servers.
let _stats = Stats::from_shards([123, 456, 789], Some(1));Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Stats
impl<'de> Deserialize<'de> for Stats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,